@@ -2,7 +2,8 @@
 
 #
 # dbcolscorrelate.pm
-# Copyright (C) 1998-2021 by John Heidemann <johnh@isi.edu>
+# Copyright (C) 1998-2008 by John Heidemann <johnh@isi.edu>
+# $Id$
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -29,14 +30,14 @@ With exactly two columns, a new column I<correlation> is created.
 
 With more than two columns, correlations are computed for each
 pairwise combination of rows, and each output column
-is given a name which is the concatenation of the two source rows,
+is given a name which is the concatination of the two source rows,
 joined with an underscore.
 
 By default, we compute the I<population correlation coefficient>
-(usually designed rho, E<0x03c1>)
+(usually designed rho, ρ)
 and assume we see all members of the population.
 With the B<--sample> option we instead compute the
-I<sample correlation coefficient>, usually designated I<r>.
+I<sample correlation coefficient>, usually desginated I<r>.
 (Be careful in that the default here to full-population
 is the I<opposite> of the default in L<dbcolstats>.)
 
@@ -49,12 +50,12 @@ This program requires a complete copy of the input data on disk.
 =item B<--sample>
 
 Select a the Pearson product-moment correlation coefficient
-(the "sample correlation coefficient", usually designated I<r>).
+(the "sample correlation coefficient", usually desginated I<r>).
 
 =item B<--nosample>
 
 Select a the Pearson product-moment correlation coefficient
-(the "sample correlation coefficient", usually designated I<r>).
+(the "sample correlation coefficient", usually desginated I<r>).
 
 
 
@@ -63,13 +64,6 @@ Select a the Pearson product-moment correlation coefficient
 Specify a L<printf(3)>-style format for output statistics.
 Defaults to C<%.5g>.
 
-=item B<-T TmpDir>
-
-where to put tmp files.
-Also uses environment variable TMPDIR, if -T is 
-not specified.
-Default is /tmp.
-
 =back
 
 =for comment
@@ -140,9 +134,7 @@ end_standard_fsdb_options
 =head1 SEE ALSO
 
 L<Fsdb>,
-L<dbcolstatscores>,
-L<dbcolsregression>,
-L<dbrvstatdiff>.
+L<dbcolstatscores>
 
 
 =head1 CLASS FUNCTIONS
@@ -199,7 +191,6 @@ sub set_defaults ($) {
     $self->{_include_non_numeric} = undef;
     $self->{_sample} = undef;
     $self->{_fscode} = undef;
-    $self->set_default_tmpdir;
 }
 
 =head2 parse_options
@@ -222,11 +213,10 @@ sub parse_options ($@) {
 	'autorun!' => \$self->{_autorun},
 	'd|debug+' => \$self->{_debug},
 	'f|format=s' => \$self->{_format},
-	'F|fs|cs|fieldseparator|columnseparator=s' => \$self->{_fscode},
+	'F|fs|cs|fieldseperator|columnseperator=s' => \$self->{_fscode},
 	'i|input=s' => sub { $self->parse_io_option('input', @_); },
 	'log!' => \$self->{_logprog},
 	's|sample!' =>  \$self->{_sample},
-	'T|tmpdir|tempdir=s' => \$self->{_tmpdir},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
 	) or pod2usage(2);
     push (@{$self->{_columns}}, @argv);
@@ -245,17 +235,17 @@ sub setup ($) {
 
     $self->finish_io_option('input', -comment_handler => $self->create_pass_comments_sub);
 
-    croak($self->{_prog} . ": at least two columns must be specified to compute a correlation.\n")
+    croak $self->{_prog} . ": at least two columns must be specified to compute a correlation.\n"
 	if ($#{$self->{_columns}} < 1);
     my @output_columns;
     my %columns_processed;
     foreach my $i (0..$#{$self->{_columns}}) {
 	my $column = $self->{_columns}[$i];
-	croak($self->{_prog} . ": column $column is double-listed as an input column (not allowed).\n")
+	croak $self->{_prog} . ": column $column is double-listed as an input column (not allowed).\n"
 	    if (defined($columns_processed{$column}));
 	$columns_processed{$column} = 1;
 	$self->{_colis}[$i] = $self->{_in}->col_to_i($column);
-	croak($self->{_prog} . ": column $column does not exist in the input stream.\n")
+	croak $self->{_prog} . ": column $column does not exist in the input stream.\n"
 	    if (!defined($self->{_colis}[$i]));
 	foreach my $j (0..$#{$self->{_columns}}) {
 	    next if ($i >= $j);
@@ -307,27 +297,21 @@ sub run ($) {
     while ($fref = &$read_fastpath_sub()) {
 	# copy and send to stats
 	$copy_writer->write_rowobj($fref);
-	# with forking we have to close output explicitly
-	# otherwise we block on the pipe(2) to the subprocesses.
 	foreach (0..$#$columns_aref) {
 	    $stats_sinks[$_]->write_row($fref->[$colis_aref->[$_]]);
 	};
     };
     # close up both
     $copy_writer->close;
-    foreach (0..$#$columns_aref) {
-	$stats_sinks[$_]->close;
-	$stats_sinks[$_] = undef;
-    };
     my @means;
     my @stddevs;
     foreach (0..$#$columns_aref) {
 	my $stats_href = dbpipeline_close2_hash($stats_source_queues[$_], $stats_sinks[$_], $stats_threads[$_]);
 	$means[$_] = $stats_href->{'mean'};
-	croak($self->{_prog} . ": column " . $columns_aref->[$_] . " does not have valid mean.\n")
+	croak $self->{_prog} . ": column " . $columns_aref->[$_] . " does not have valid mean.\n"
 	    if (!defined($means[$_]));
 	$stddevs[$_] = $stats_href->{'stddev'};
-	croak($self->{_prog} . ": column " . $columns_aref->[$_] . " does not have valid standard deviation.\n")
+	croak $self->{_prog} . ": column " . $columns_aref->[$_] . " does not have valid standard deviation.\n"
 	    if (!defined($stddevs[$_]));
     };
 
@@ -393,7 +377,7 @@ sub run ($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 1998-2021 by John Heidemann <johnh@isi.edu>
+Copyright (C) 1991-2008 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
