@@ -2,7 +2,8 @@
 
 #
 # dbfilepivot.pm
-# Copyright (C) 2011-2018 by John Heidemann <johnh@isi.edu>
+# Copyright (C) 2011 by John Heidemann <johnh@isi.edu>
+# $Id: 628d1e4630cc337fef1056df75e3cef8b51b2ad4 $
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -21,16 +22,14 @@ dbfilepivot [-e empty] -k KeyField -p PivotField [-v ValueField]
 
 =head1 DESCRIPTION
 
-Pivot a table, converting multiple rows corresponding to the 
+Pivot a table, converting multiple rows correponding to the 
 same key into a single wide row.
 
 In a normalized database, one might have data with a schema like
 (id, attribute, value),
 but sometimes it's more convenient to see the data with a schema like
 (id, attribute1, attribute2).
-(For example, gnuplot's stacked histograms requires denormalized data.)
-Dbfilepivot converts the normalized format to the denormalized,
-but sometimes useful, format.
+This tool converts the first to the second.
 Here the "id" is the key, the attribute is the "pivot",
 and the value is, well, the optional "value".
 
@@ -40,7 +39,7 @@ An example is clearer.  A gradebook usually looks like:
     John       97  98  99
     Paul       -   80  82
 
-but a properly normalized format would represent it as:
+but one could also represent it as
 
     #fsdb name hw score
     John       1  97
@@ -51,40 +50,27 @@ but a properly normalized format would represent it as:
 
 This tool converts the second form into the first, when used as
 
-    dbfilepivot -k name -p hw -v score
-
-or
-
-    dbfilepivot --possible-pivots='1 2 3' -k name -p hw -v score
+    dbfilepivot -k hw score
 
 Here name is the I<key> column that indicates which rows belong
 to the same entity,
 hw is the I<pivot> column that will be indicate which column
 in the output is relevant,
-and score is the I<value> that indicates what goes in the
+and score is the value that indicates what goes in the
 output.
 
 The pivot creates a new column C<key_tag1>, C<key_tag2>, etc.
-for each tag, the contents of the pivot field in the input.
+for each tag, the contents of the key field in the input.
 It then populates those new columns with the contents of the value field
 in the input.
 
 If no value column is specified, then values are either empty or 1.
 
+Dbfilepivot makes two passes over its data
+and so requires temporary disk space equal to the input size.
+
 Dbfilepivot assumes all lines with the same key are adjacent
 in the input source, like L<dbmapreduce(1)> with the F<-S> option.
-To enforce this invariant, by default, it I<requires> input be sorted by key.
-
-There is no requirement that the pivot field be sorted (provided the key field is already sorted).
-
-By default, dbfilepivot makes two passes over its data
-and so requires temporary disk space equal to the input size.
-With the B<--possible-pivots> option, the user can specify pivots
-and skip the second pass and avoid temporary data storage.
-
-Memory usage is proportional to the number of unique pivot values.
-
-The inverse of this commend is L<dbcolsplittorows>.
 
 
 =head1 OPTIONS
@@ -107,11 +93,6 @@ Required (no default).
 Specify which column is the value in the output.
 If none is given, 1 is used for the value.
 
-=item B<--possible-pivots PP>
-
-Specify all possible pivot values as PP, a whitespace-separated list.
-With this option, data is processed only once (not twice).
-
 =item B<-C S> or B<--element-separator S>
 
 Specify the separator I<S> used to join the input's key column
@@ -124,9 +105,8 @@ give value E as the value for empty (null) records
 
 =item B<-S> or B<--pre-sorted>
 
-Assume data is already grouped by key.
-Provided twice, it removes the validation of this assertion.
-By default, we sort by key.
+Assume data is already grouped by tag.
+Provided twice, it removes the validiation of this assertion.
 
 =item B<-T TmpDir>
 
@@ -183,12 +163,9 @@ end_standard_fsdb_options
 
 =head2 Input:
 
-	#fsdb name hw score
-	John       1  97
-	John       2  98
-	John       3  99
-	Paul       2  80
-	Paul       3  82
+    #fsdb name hw_1 hw_2 hw_3
+    John       97  98  99
+    Paul       -   80  82
 
 =head2 Command:
 
@@ -196,10 +173,12 @@ end_standard_fsdb_options
 
 =head2 Output:
 
-	#fsdb name hw_1 hw_2 hw_3
-	John	97	98	99
-	Paul	-	80	82
-	#   | dbfilepivot -k name -p hw -v score
+    #fsdb name hw score
+    John       1  97
+    John       2  98
+    John       3  99
+    Paul       2  80
+    Paul       3  82
 
 =head1 SEE ALSO
 
@@ -224,7 +203,6 @@ use Fsdb::Filter;
 use Fsdb::IO::Reader;
 use Fsdb::IO::Writer;
 use Fsdb::IO::Replayable;
-use Fsdb::Filter::dbpipeline qw(dbpipeline_filter dbsort);
 
 
 =head2 new
@@ -262,10 +240,6 @@ sub set_defaults ($) {
     $self->{_key_column} = undef;
     $self->{_pivot_column} = undef;
     $self->{_value_column} = undef;
-    $self->{_pre_sorted} = 0;
-    $self->{_sort_order} = undef;
-    $self->{_sort_as_numeric} = undef;
-    $self->{_possible_pivots} = undef;
 }
 
 =head2 parse_options
@@ -294,92 +268,12 @@ sub parse_options ($@) {
 	'log!' => \$self->{_logprog},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
 	'p|pivot=s' => \$self->{_pivot_column},
-	'possible-pivots=s' => \$self->{_possible_pivots},
-	'S|pre-sorted+' => \$self->{_pre_sorted},
 	'T|tmpdir|tempdir=s' => \$self->{_tmpdir},
 	'v|value=s' => \$self->{_value_column},
-	# sort key options:
-	'n|numeric' => sub { $self->{_sort_as_numeric} = 1; },
-	'N|lexical' => sub { $self->{_sort_as_numeric} = undef; },
-	'r|descending' => sub { $self->{_sort_order} = -1; },
-	'R|ascending' => sub { $self->{_sort_order} = 1; },
 	) or pod2usage(2);
     pod2usage(2) if ($#argv != -1);
 }
 
-=head2 _find_possible_pivots
-
-    $filter->_find_possible_pivots();
-
-Internal: scan input data to find all possible pivot values.
-
-Returns npivots, pivots_aref.
-
-=cut
-
-sub _find_possible_pivots($) {
-    my($self) = @_;
-
-    #
-    # Read the data to find all possible pivots,
-    # saving a copy as we go.
-    #
-    $self->{_replayable} = new Fsdb::IO::Replayable(-writer_args => [ -clone => $self->{_in} ], -reader_args => [ -comment_handler => $self->create_pass_comments_sub ]);
-    my $save_out = $self->{_replayable_writer} = $self->{_replayable}->writer;
-    my $read_fastpath_sub = $self->{_in}->fastpath_sub();
-    my $save_write_fastpath_sub = $save_out->fastpath_sub;
-    my $fref;
-    my %pivots;
-    my $npivots = 0;
-    my $loop = q(
-	    # first pass: reading data to find all possible pivots
-	    while ($fref = &$read_fastpath_sub) {
-		my $value = $fref->[) . $self->{_pivot_coli} . q@];
-		if ($value ne '@ . $self->{_empty} . q@') {
-		    $npivots++ if (!defined($pivots{$value}));
-		    $pivots{$value} = 1;
-		};
-		&$save_write_fastpath_sub($fref);
-	    };
-	@;
-    print $loop if ($self->{_debug});
-    eval $loop;
-    $@ && croak($self->{_prog} . ": internal eval error: $@.\n");
-
-    if (defined($self->{_sorter_fred})) {
-	$self->{_sorter_fred}->join();
-	$self->{_sorter_fred} = undef;
-    };
-
-    $self->{_replayable}->close;
-
-    my(@pivots) = keys %pivots;
-
-    return ($npivots, \@pivots);
-}
-
-
-=head2 _given_possible_pivots
-
-    $filter->_given_possible_pivots();
-
-Internal: parse option of possible pivots.
-
-Returns npivots, pivots_href.
-
-=cut
-
-sub _given_possible_pivots($) {
-    my($self) = @_;
-
-    #
-    # All possible pivots are given by the user.
-    #
-    my @pivots = split(/\s+/, $self->{_possible_pivots});
-    return ($#pivots + 1, \@pivots);
-}
-
-
 =head2 setup
 
     $filter->setup();
@@ -391,47 +285,56 @@ Internal: setup, parse headers.
 sub setup ($) {
     my($self) = @_;
 
-    croak($self->{_prog} . ": invalid empty value (single quote).\n")
+    croak $self->{_prog} . ": invalid empty value (single quote).\n"
 	if ($self->{_empty} eq "'");
 
-    #
-    # guarantee data is sorted
-    # (swap reader if necessary)
-    if ($self->{_pre_sorted}) {
-	# pre-sorted, so just read it
-	$self->finish_io_option('input', -comment_handler => $self->create_delay_comments_sub);
-	$self->{_sorter_fred} = undef;
-    } else {
-	# not sorted, so sort it and read that
-	my @sort_args = ('--nolog', $self->{_key_column});
-	unshift(@sort_args, '--descending') if ($self->{_sort_order} == -1);
-	unshift(@sort_args, ($self->{_sort_as_numeric} ? '--numeric' : '--lexical'));
-	my($new_reader, $new_fred) = dbpipeline_filter($self->{_input}, [-comment_handler => $self->create_delay_comments_sub], dbsort(@sort_args));
-	$self->{_pre_sorted_input} = $self->{_input};
-	$self->{_in} = $new_reader;
-	$self->{_sorter_fred} = $new_fred;
-    };
+    $self->finish_io_option('input', -comment_handler => $self->create_pass_comments_sub('_replayable_writer'));
 
     pod2usage(2) if (!defined($self->{_key_column}));
     $self->{_key_coli} = $self->{_in}->col_to_i($self->{_key_column});
-    croak($self->{_prog} . ": key column " . $self->{_key_column} . " is not in input stream.\n")
+    croak $self->{_prog} . ": key column " . $self->{_key_column} . " is not in input stream.\n"
 	    if (!defined($self->{_key_coli}));
 
     pod2usage(2) if (!defined($self->{_pivot_column}));
     $self->{_pivot_coli} = $self->{_in}->col_to_i($self->{_pivot_column});
-    croak($self->{_prog} . ": pivot column " . $self->{_pivot_column} . " is not in input stream.\n")
+    croak $self->{_prog} . ": pivot column " . $self->{_pivot_column} . " is not in input stream.\n"
 	    if (!defined($self->{_pivot_coli}));
 
     if (defined($self->{_value_column})) {
 	$self->{_value_coli} = $self->{_in}->col_to_i($self->{_value_column});
-        croak($self->{_prog} . ": value column " . $self->{_value_column} . " is not in input stream.\n")
+        croak $self->{_prog} . ": value column " . $self->{_value_column} . " is not in input stream.\n"
 	    if (!defined($self->{_value_coli}));
     };
 
-    my($npivots, $pivots_aref) = (defined($self->{_possible_pivots}) ? $self->_given_possible_pivots() : $self->_find_possible_pivots());
-    croak($self->{_prog} . ": no input data or pivots\n")
+    #
+    # Read the data to find all possible pivots,
+    # saving a copy as we go.
+    #
+    $self->{_replayable} = new Fsdb::IO::Replayable(-writer_args => [ -clone => $self->{_in} ], -reader_args => [ -comment_handler => $self->create_pass_comments_sub ]);
+    my $save_out = $self->{_replayable}->writer;
+    my $read_fastpath_sub = $self->{_in}->fastpath_sub();
+    my $save_write_fastpath_sub = $save_out->fastpath_sub;
+    my $fref;
+    my %pivots;
+    my $npivots = 0;
+    my $loop = q(
+	    while ($fref = &$read_fastpath_sub) {
+		my $value = $fref->[) . $self->{_pivot_coli} . q@];
+		if ($value ne '@ . $self->{_empty} . q@') {
+		    $pivots{$value} = 1;
+		    $npivots++;
+		};
+		&$save_write_fastpath_sub($fref);
+	    };
+	@;
+    print $loop if ($self->{_debug});
+    eval $loop;
+    $@ && croak $self->{_prog} . ": interal eval error: $@.\n";
+    $self->{_replayable}->close;
+    croak $self->{_prog} . ": no input data or pivots\n"
 	if ($npivots == 0);
 
+
     #
     # Now that we know the pivots, make the new columns.
     #
@@ -441,13 +344,11 @@ sub setup ($) {
 		        @{$self->{_in}->cols});
     $self->finish_io_option('output', -clone => $self->{_in}, -cols => \@new_cols, -outputheader => 'delay');
     my %tag_colis;
-    my %new_columns;
-    foreach (sort @$pivots_aref) {
+    foreach (sort keys %pivots) {
 	# xxx: could try to sort numerically if all pivots are numbers
 	my $new_column = $self->{_pivot_column} . $self->{_elem_separator} . $_;
-	$new_columns{$new_column} = 1;
         $self->{_out}->col_create($new_column)
-	    or croak($self->{_prog} . ": cannot create column $new_column (maybe it already existed?)\n");
+	    or croak $self->{_prog} . ": cannot create column $new_column (maybe it already existed?)\n";
 	$tag_colis{$_} = $self->{_out}->col_to_i($new_column);
     };
     $self->{_tag_colis_href} = \%tag_colis;
@@ -463,7 +364,7 @@ sub setup ($) {
     $self->{_old_mapping_code} = $old_mapping_code;
     # and initialize the new
     my $new_initialization_code = '';
-    foreach (sort keys %new_columns) {
+    foreach (sort keys %pivots) {
 	$new_initialization_code .= '$nf[' . $self->{_out}->col_to_i($_) . '] = ' . "\n";
     };
     $new_initialization_code .= "\t'" . $self->{_empty} . "';\n";
@@ -480,8 +381,8 @@ Internal: run over each rows.
 sub run ($) {
     my($self) = @_;
 
-    my $in_reader = (defined($self->{_replayable}) ? $self->{_replayable}->reader : $self->{_in});
-    my $read_fastpath_sub = $in_reader->fastpath_sub();
+    my $replayable_reader = $self->{_replayable}->reader;
+    my $read_fastpath_sub = $replayable_reader->fastpath_sub();
     my $write_fastpath_sub = $self->{_out}->fastpath_sub();
 
     #
@@ -493,10 +394,6 @@ sub run ($) {
     # given we assume sorted input.
     #
     my $emit_nf_code = '&$write_fastpath_sub(\@nf);';
-    my $check_ordering_code = '
-	die("' . $self->{_prog} . q': keys $old_key and $new_key are out-of-order\n") if ($old_key gt $new_key);
-    ';
-    $check_ordering_code = '' if ($self->{_pre_sorted} > 1);
     my $value_value = (defined($self->{_value_column})) ? '$fref->[' . $self->{_value_coli} . ']' : '1';
     my $tag_colis_href = $self->{_tag_colis_href};
     my($loop) = q'
@@ -508,18 +405,13 @@ sub run ($) {
 	    my $new_key = $fref->[' . $self->{_key_coli} . '];
 	    if (!defined($old_key) || $old_key ne $new_key) {
 		if (defined($old_key)) {
-		    ' . $emit_nf_code . 
-		    $check_ordering_code . '
+		    ' . $emit_nf_code . '
 		};
 		' . $self->{_new_initialization_code} . '
 		' . $self->{_old_mapping_code} . '
 		$old_key = $new_key;
 	    };
-	    my $pivot_value = $fref->[' . $self->{_pivot_coli} . '];
-	    my $target_coli = $tag_colis_href->{$pivot_value};
-	    die $self->{_prog} . ": unanticipated pivot value $pivot_value (forgot it in --possible-pivots?).\n"
-		if (!defined($target_coli));
-	    $nf[$target_coli] = ' . $value_value . ';
+	    $nf[$tag_colis_href->{$fref->[' . $self->{_pivot_coli} . ']}] = ' . $value_value . ';
         };
 	if (defined($old_key)) {
 	    ' . $emit_nf_code . "
@@ -527,27 +419,13 @@ sub run ($) {
     }\n";
     print $loop if ($self->{_debug});
     eval $loop;
-    if ($@) {
-	# propagate sort failure cleanly
-	if ($@ =~ /^$self->{_prog}/) {
-	    croak("$@");
-	} else {
-	    croak($self->{_prog} . ": internal eval error: $@.\n");
-	};
-    };
-
-    # If single pass, we may need to collect this thread here.
-    if (defined($self->{_sorter_fred})) {
-	$self->{_sorter_fred}->join();
-	$self->{_sorter_fred} = undef;
-    };
-
+    $@ && croak $self->{_prog} . ": interal eval error: $@.\n";
 }
 
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 2011-2018 by John Heidemann <johnh@isi.edu>
+Copyright (C) 2011 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
