@@ -3,7 +3,8 @@
 #
 # dbrvstatdiff
 #
-# Copyright (C) 1991-2021 by John Heidemann <johnh@isi.edu>
+# Copyright (C) 1991-2008 by John Heidemann <johnh@isi.edu>
+# $Id$
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -28,8 +29,6 @@ OR
 =head1 DESCRIPTION
 
 Produce statistics on the difference of sets of random variables.
-If a hypothesized difference is given
-(with C<-h>), to does a Student's t-test.
 
 Random variables are specified by:
 
@@ -79,7 +78,7 @@ either "rejected" or "not-rejected".
 
 =item C<t_test_break>
 
-The hypothesized value that is break-even point
+The hypothesised value that is break-even point
 for the T-test.
 
 =item C<t_test_break_pct>
@@ -92,7 +91,7 @@ Confidence intervals are not printed if standard deviations are not provided.
 Confidence intervals assume normal distributions with common variances.
 
 T-tests are only computed if a hypothesized difference is provided.
-Hypothesized differences should be proceeded by <=, >=, =.
+Hypothesized diferences should be proceeded by <=, >=, =.
 T-tests assume normal distributions with common variances.
 
 =head1 OPTIONS
@@ -112,7 +111,7 @@ Defaults to C<%.5g>.
 
 =item B<-h DIFF> or B<--hypothesis DIFF>
 
-Specify the hypothesized difference as C<DIFF>,
+Specify the hypothoesized difference as C<DIFF>,
 where C<DIFF> is something like C<E<lt>=0> or C<E<gt>=0>, etc.
 
 =back
@@ -218,57 +217,15 @@ from two experiments, and to use dbrvstatdiff to see if they are different.
     cat two_trial.fsdb | 
 	dbmultistats -k case value |
 	dbcolcopylast mean stddev n |
-	dbrow '_case eq "b"' |
-	dbrvstatdiff -h '=0' mean stddev n copylast_mean copylast_stddev copylast_n |
-	dblistize
+	dbrvstatdiff mean stddev n copylast_mean copylast_stddev copylast_n
 
 =head3 Output 3:
 
-	#fsdb -R C case mean stddev pct_rsd conf_range conf_low conf_high conf_pct sum sum_squared min max n copylast_mean copylast_stddev copylast_n diff diff_pct diff_conf_half diff_conf_low diff_conf_high diff_conf_pct_half diff_conf_pct_low diff_conf_pct_high t_test t_test_result t_test_break t_test_break_pct
-	case: b
-	mean: 1.98
-	stddev: 0.083666
-	pct_rsd: 4.2256
-	conf_range: 0.10387
-	conf_low: 1.8761
-	conf_high: 2.0839
-	conf_pct: 0.95
-	sum: 9.9
-	sum_squared: 19.63
-	min: 1.9
-	max: 2.1
-	n: 5
-	copylast_mean: 1.02
-	copylast_stddev: 0.083666
-	copylast_n: 5
-	diff: -0.96
-	diff_pct: -48.485
-	diff_conf_half: 0.12202
-	diff_conf_low: -1.082
-	diff_conf_high: -0.83798
-	diff_conf_pct_half: 6.1627
-	diff_conf_pct_low: -54.648
-	diff_conf_pct_high: -42.322
-	t_test: -18.142
-	t_test_result: rejected
-	t_test_break: -1.082
-	t_test_break_pct: -54.648
-	
-	#  | dbmultistats -k case value
-	#   | dbcolcopylast mean stddev n
-	#   | dbrow _case eq "b"
-	#   | dbrvstatdiff -h =0 mean stddev n copylast_mean copylast_stddev copylast_n
-	#   | dbfilealter -R C
-
-(So one cannot say that they are statistically equal.)
-
-
 =head1 SEE ALSO
 
-L<Fsdb>,
-L<dbcolstats>,
-L<dbcolcopylast>,
-L<dbcolscorrelate>.
+L<Fsdb>.
+L<dbcolstats>.
+L<dbcolcopylast>.
 
 
 =head1 CLASS FUNCTIONS
@@ -378,8 +335,8 @@ sub setup ($) {
 	$self->{_hyp_class} = -1 if ($hyp_class eq '<=');
 	$self->{_hyp_class} = 0 if ($hyp_class =~ /^==?$/);
 	$self->{_hyp_class} = 1 if ($hyp_class eq '>=');
-	croak($self->{_prog} . ": bad hypothesis specification ``" .
-		$self->{_hypothesis} . "''; not of format <=N, =N, >=N, where N is some number.\n")
+	croak $self->{_prog} . ": bad hypothesis specification ``" .
+		$self->{_hypothesis} . "''; not of format <=N, =N, >=N, where N is some number.\n"
 		if (!defined($self->{_hyp_class}) || !defined($hyp_diff));
 	$self->{_hyp_diff} = $hyp_diff;
     };
@@ -393,7 +350,7 @@ sub setup ($) {
     } elsif ($#{$self->{_arg_fields}} == 3) {
 	($self->{_m1_column}, $self->{_n1_column}, $self->{_m2_column}, $self->{_n2_column}) = @{$self->{_arg_fields}};
         $self->{_ss1_column} = $self->{_ss2_column} = undef;
-	croak($self->{_prog} . ": T-tests require standard deviations, but none were given as arguments.\n")
+	croak $self->{_prog} . ": T-tests require standard deviations, but none were given as arguments.\n"
 	    if (defined($self->{_hyp_diff}));
     } else {
 	carp $self->{_prog} . ": confusing number of fields given; cannot identify desired type of stats.\n";
@@ -411,7 +368,7 @@ sub setup ($) {
 	next if (!defined($self->{$_}));   # maybe unspecified sum-of-squares
 	$coli =~ s/_column/_coli/;
 	$self->{$coli} = $self->{_in}->col_to_i($self->{$_});
-	croak($self->{_prog} . ": unknown selected input column ``$_''.\n")
+	croak $self->{_prog} . ": unknown selected input column ``$_''.\n"
 	    if (!defined($self->{$coli}));
     };
 
@@ -423,9 +380,9 @@ sub setup ($) {
 	if (defined($self->{_hypothesis}));
     foreach (@new_columns) {
 	$self->{_out}->col_create($_)
-	    or croak($self->{_prog} . ": cannot create column ``$_'' (maybe it already existed?)\n");
+	    or croak $self->{_prog} . ": cannot create column ``$_'' (maybe it already existed?)\n";
 	$self->{"_${_}_coli"} = $self->{_out}->col_to_i($_);
-	defined($self->{"_${_}_coli"}) or croak("internal error\n");
+	defined($self->{"_${_}_coli"}) or croak "internal error\n";
     };
 
 }
@@ -542,7 +499,7 @@ sub run ($) {
         if (defined($self->{_hypothesis})) {
             $fref->[$t_test_f] = sprintf("$format", $t_test);
             $fref->[$t_test_result_f] = $t_test_result;
-            $fref->[$t_test_break_f] = sprintf("$format", $t_test_break);
+            $fref->[$t_test_break_f] = $t_test_break;
             $fref->[$t_test_break_pct_f] = sprintf("$format", $t_test_break_pct);
         };
     
@@ -553,7 +510,7 @@ sub run ($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 1991-2021 by John Heidemann <johnh@isi.edu>
+Copyright (C) 1991-2008 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
